@@ -2,7 +2,9 @@ package PDK::Device::ConfigBackup;
 
 use v5.30;
 use Moose;
-use Carp qw(croak);
+use Carp       qw(croak);
+use File::Path qw(make_path);
+use Data::Dumper;
 use Parallel::ForkManager;
 use Thread::Queue;
 use namespace::autoclean;
@@ -13,7 +15,7 @@ with 'PDK::Device::Concern::Dumper';
 has queue => (
   is      => 'rw',
   default => sub {
-    my $value = $ENV{PDK_DEVICE_QUEUE};
+    my $value = $ENV{PDK_DEVICE_BACKUP_QUEUE};
     PDK::Device::Concern::Dumper::_debug_init("从环境变量中加载并设置 queue：($value)") if defined $value;
     return $value // 10;
   },
@@ -50,13 +52,13 @@ sub getConfigJob {
   eval {
     $devices = $self->assignAttributes($devices);
     my $count = scalar(@{$devices});
-    $self->dump("开始任务：并行执行 ($count) 台设备的配置获取任务");
+    $self->dump("开始配置备份任务：并行执行 ($count) 台设备的配置获取任务");
   };
   if (!!$@) {
     croak "自动加载并装配模块抛出异常: $@";
   }
 
-  my $pm    = Parallel::ForkManager->new(10);
+  my $pm    = Parallel::ForkManager->new($self->{queue});
   my $queue = Thread::Queue->new();
 
   $pm->run_on_finish(sub {
@@ -65,6 +67,7 @@ sub getConfigJob {
   });
 
   foreach my $device (@{$devices}) {
+    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 配置备份任务");
     $pm->start and next;
     my $status = $self->startGetConfig($device);
     $pm->finish(0, $status);
@@ -75,6 +78,7 @@ sub getConfigJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
+  $self->dump("配置备份任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
@@ -91,13 +95,13 @@ sub ftpConfigJob {
   eval {
     $devices = $self->assignAttributes($devices);
     my $count = scalar(@{$devices});
-    $self->dump("开始任务：并行执行 ($count) 台设备的配置获取任务");
+    $self->dump("开始FTP配置备份任务：并行执行 ($count) 台设备的配置获取任务");
   };
   if (!!$@) {
     croak "自动加载并装配模块抛出异常: $@";
   }
 
-  my $pm    = Parallel::ForkManager->new(10);
+  my $pm    = Parallel::ForkManager->new($self->{queue});
   my $queue = Thread::Queue->new();
 
   $pm->run_on_finish(sub {
@@ -106,6 +110,7 @@ sub ftpConfigJob {
   });
 
   foreach my $device (@{$devices}) {
+    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) FTP配置备份任务");
     $pm->start and next;
     my $status = $self->startFtpConfig($device);
     $pm->finish(0, $status);
@@ -116,6 +121,7 @@ sub ftpConfigJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
+  $self->dump("FTP配置备份任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
@@ -138,7 +144,7 @@ sub execCommandsJob {
     croak "自动加载并装配模块抛出异常: $@";
   }
 
-  my $pm    = Parallel::ForkManager->new(10);
+  my $pm    = Parallel::ForkManager->new($self->{queue});
   my $queue = Thread::Queue->new();
 
   $pm->run_on_finish(sub {
@@ -147,6 +153,7 @@ sub execCommandsJob {
   });
 
   foreach my $device (@{$devices}) {
+    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发任务");
     $pm->start and next;
     my $status = $self->startExecCommands($device, $commands);
     $pm->finish(0, $status);
@@ -157,6 +164,7 @@ sub execCommandsJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
+  $self->dump("脚本自动下发任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
@@ -173,14 +181,14 @@ sub runCommandsJob {
   foreach my $device (@{$devices}) {
     if (!$device->{commands} || @{$device->{commands}} == 0) {
       $self->dump("[runCommandsJob/前置检查阶段]：所有设备的命令列表都不能为空");
-      die "设备 " . $device->{name} . " 的命令列表为空";
+      croak "设备 " . $device->{name} . " 的命令列表为空";
     }
   }
 
   eval {
     $devices = $self->assignAttributes($devices);
     my $count = scalar(@{$devices});
-    $self->dump("开始任务：并行执行 ($count) 台设备的配置下发任务，推送的脚本各自独立");
+    $self->dump("开始配置推送任务：并行执行 ($count) 台设备的配置下发任务，推送的脚本各自独立");
   };
   if (!!$@) {
     croak "自动加载并装配模块抛出异常: $@";
@@ -195,6 +203,7 @@ sub runCommandsJob {
   });
 
   foreach my $device (@{$devices}) {
+    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发(高权模式)任务");
     $pm->start and next;
     my $commands = $device->{commands};
     my $status   = $self->startExecCommands($device, $commands);
@@ -206,6 +215,7 @@ sub runCommandsJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
+  $self->dump("脚本自动下发(高权模式)任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
@@ -218,7 +228,7 @@ sub runCommandsJob {
 
 sub ftpConfig {
   my ($self, $param) = @_;
-  $self->dump("开始任务：对设备($param->{name}/$param->{ip})执行 FTP 备份操作");
+  $self->dump("开始FTP配置备份任务：对设备($param->{name}/$param->{ip})执行 FTP 备份操作");
 
   my $result;
   eval {
@@ -240,7 +250,7 @@ sub ftpConfig {
 
 sub getConfig {
   my ($self, $param) = @_;
-  $self->dump("开始任务：对设备($param->{name}/$param->{ip})执行配置获取操作");
+  $self->dump("开始配置备份任务：对设备($param->{name}/$param->{ip})执行配置获取操作");
 
   my $result;
   eval {
@@ -250,12 +260,13 @@ sub getConfig {
   if (!!$@) {
     $result = {success => 0, reason => $@};
   }
+
   return $result;
 }
 
 sub execCommands {
   my ($self, $param, $commands) = @_;
-  $self->dump("开始任务：对设备($param->{name}/$param->{ip})执行命令下发操作");
+  $self->dump("开始配置下发任务：对设备($param->{name}/$param->{ip})执行命令下发操作");
 
   my $result;
   eval {
@@ -271,7 +282,7 @@ sub execCommands {
 
 sub startFtpConfig {
   my ($self, $param) = @_;
-  $self->dump("激活任务：对设备($param->{name}/$param->{ip})执行 FTP 备份并记录结果");
+  $self->dump("激活FTP备份成功任务：对设备($param->{name}/$param->{ip})执行 FTP 备份并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -281,9 +292,11 @@ sub startFtpConfig {
 
   if ($result->{success}) {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) FTP 备份成功";
+    $self->dump("FTP备份成功：设备 $name($ip) FTP 备份成功");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) FTP 备份失败: $result->{reason}";
+    $self->dump("FTP备份失败：设备 $name($ip) FTP 备份异常: $result->{reason}");
   }
 
   return $status;
@@ -291,7 +304,7 @@ sub startFtpConfig {
 
 sub startExecCommands {
   my ($self, $param, $commands) = @_;
-  $self->dump("激活任务：对设备($param->{name}/$param->{ip})命令下发并记录结果");
+  $self->dump("激活配置下发任务：对设备($param->{name}/$param->{ip})命令下发并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -303,9 +316,11 @@ sub startExecCommands {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) 配置下发成功";
     my $filename = "${name}_${ip}_execCommands.txt";
     $self->write_file($result->{result}, $filename);
+    $self->dump("配置下发成功：设备 $name($ip) 配置下发成功，快照保存在文件 $filename");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) 配置下发失败: $result->{reason}";
+    $self->dump("配置下发失败：设备 $name($ip) 配置下发异常: $result->{reason}");
   }
 
   return $status;
@@ -314,7 +329,7 @@ sub startExecCommands {
 sub startGetConfig {
   my ($self, $param) = @_;
 
-  $self->dump("激活任务：对设备($param->{name}/$param->{ip})配置获取并记录结果");
+  $self->dump("激活配置备份任务：对设备($param->{name}/$param->{ip})配置获取并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -326,13 +341,35 @@ sub startGetConfig {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) 配置备份成功";
     my $filename = "${name}_${ip}_getConfig.txt";
     $self->write_file($result->{config}, $filename);
+    $self->dump("配置备份成功：设备 $name($ip) 配置备份成功，快照保存在文件 $filename");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) 配置备份失败: $result->{reason}";
+    $self->dump("配置备份失败：设备 $name($ip) 配置备份任务异常: $result->{reason}");
   }
 
   return $status;
 }
 
+sub dump {
+  my ($self, $msg) = @_;
+
+  $msg .= ';' unless $msg =~ /^\s*$/ || $msg =~ /[,，！!。.]$/;
+
+  my $text = $self->now() . " - [debug] $msg";
+  if ($self->debug == 1) {
+    say $text;
+  }
+  elsif ($self->debug > 1) {
+    my $workdir = "$self->{workdir}/dump/$self->{month}/$self->{date}";
+    make_path($workdir) unless -d $workdir;
+
+    my $filename = "$workdir/dump_log.txt";
+    open(my $fh, '>>', $filename) or croak "无法打开文件 $filename 进行写入: $!";
+    print $fh "$text\n"           or croak "写入文件 $filename 失败: $!";
+    close($fh)                    or croak "关闭文件句柄 $filename 失败: $!";
+  }
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
